# Enums

This module contains enumeration classes used throughout NeoPika.

::: neopika.enums
    handler: python
    options:
      members: true
      show_root_heading: false
      show_source: true
      heading_level: 2 